


/* Start:/js/libs/jquery.simplemodal/basic.css*/
/*
 * SimpleModal Basic Modal Dialog
 * http://simplemodal.com
 *
 * Copyright (c) 2013 Eric Martin - http://ericmmartin.com
 *
 * Licensed under the MIT license:
 *   http://www.opensource.org/licenses/mit-license.php
 */

.active-link {
  background-color: rgba(200, 200, 200, 0.7);
}


 .order-input {
	width: 200px;
 }

 .old-price {
   text-decoration: line-through;
   display: inline !important;
 }

 .discount-value {
   color: #2F9C0E;
   font-weight: bold;
 }


 .news-title {
	font-size: 16px;
	font-weight: bold;
	margin-bottom: 3px
 }

 .news-text p {
	margin-bottom: 3px;
	font-size: 14px;
 }

 .news-date {
	color: #989a9b;
	margin-bottom: 3px;
 }

.header__info__ad-header-a {
	color: rgb(47, 156, 14);
	font-family: 'Exo 2', sans-serif;
	font-size: 22px;
	font-weight: 600;
	line-height: 24px;
	margin: 0px;
}

/* .search_preview_pic {
	float: left;
  max-height: 150px;
  max-width: 150px;
  overflow: hidden;
  margin: 0px 10px;
}

.search-preview {
	float: left;
	clear: none;
} */

h2.info_payment_delivery{
        font-size: 18pt;
        color: #2f9c0e;
        font-family: 'Exo 2', sans-serif;
        margin-top: 16pt;
        margin-bottom: 5pt;
    }
    ul.info_payment_delivery{

    }
    ul.info_payment_delivery>li{
        margin-left: 20px;
        font-size: 14px;
    }

    .info_payment_delivery{
        margin: 5px 2px;
    }
    dl.info_payment_delivery>dd{
        font-weight: bold;
        margin-top:  16pt;
        margin-bottom: 3px;
        font-size: 12pt;
    }
    dl.info_payment_delivery>dt:after{
        content: '';
        display: block;
        clear: both;
        float: none;
    }
    dl.info_payment_delivery>dt {
        margin-left: 7pt;
        margin-top: 14pt;
    }
    p.info_payment_delivery {
      font-size: 14px;
    }


#basic-modal-content {display:none;}

/* Overlay */
#simplemodal-overlay {background-color:#000;}

/* Container */
#simplemodal-container {
    height:360px;
    width:600px;
    color:#bbb;
    background-color:#fff; border:0;
    padding:0;
}
#simplemodal-container .simplemodal-data {
    padding:0;
}
#simplemodal-container .simplemodal-data div.modal_content{
    padding:12pt;
    font-size: 9pt;
    color: #999;
    font-family: 'Exo 2', sans-serif;
}
/*#simplemodal-container code {background:#fff; border-left:3px solid #65B43D; color:#bbb; display:block; font-size:12px; margin-bottom:12px; padding:4px 6px 6px;}*/
/*#simplemodal-container a {color:#ddd;}*/
#simplemodal-container a.modalCloseImg {
    background:url(/js/libs/jquery.simplemodal/img/x.png) no-repeat; width:25px;
    height:29px; display:inline;
    z-index:3200;
    position:absolute;
    top:-15px;
    right:-16px;
    cursor:pointer;}
#simplemodal-container h3 {
    font-size: 16px;
    text-transform: uppercase;
    color:#fff;
    font-family: 'Exo 2', sans-serif;
    height: 32px;
    line-height: 32px;
    color: #fff;
    background-color: #1b98e0;
    padding: 0 16px;
    position: relative;
}
span.simplemodal-close{
    position: absolute;
    width: 24px;
    height: 24px;
    top: 4px;
    right: 4px;
    color: #fff;
    text-decoration: none;
    font-weight: 600;
    font-size: 12pt;
    line-height: 14pt;
    text-align: center;
    cursor: pointer;
    z-index: 100;
    font-family: 'Exo 2', sans-serif;
}
span.simplemodal_ajax_status{
    display: block;
    /*vertical-align: middle;*/
    font-size: 14pt;
    text-align: center;
    /*margin: 50% 0;*/
}
.simplemodal-data>.js-error{
    display: block;
    padding: 3pt;
    text-align: center;
}
.modal_content>.ajax_answer{
    font-size: 12pt;
}
/* End */



/* Start:/js/libs/jquery.simplemodal/basic_ie.css*/
/*
 * SimpleModal Basic Modal Dialog
 * http://simplemodal.com
 *
 * Copyright (c) 2013 Eric Martin - http://ericmmartin.com
 *
 * Licensed under the MIT license:
 *   http://www.opensource.org/licenses/mit-license.php
 */

/* IE 6 hacks */
#simplemodal-container a.modalCloseImg {background:none; right:-14px; width:22px; height:26px; filter: progid:DXImageTransform.Microsoft.AlphaImageLoader(src='img/basic/x.png',sizingMethod='scale');}
/* End */



/* Start:/js/libs/bukvus/bukvus.css*/
#bukvus {
	position: fixed;
	display: none;
	bottom: 0;
	opacity: 0.9;
	background: #333;
	width: 100%;
	padding: 10px 0;
	text-align: center;
	color: #fff;
	z-index: 99;
	cursor: pointer;
	width: 100%;
}
/* End */

/* Start:/bitrix/templates/shop/css/style.css
@font-face {
    font-family: 'FontAwesome';
    src: url('/bitrix/templates/shop/css/../fonts/awesome/fontawesome-webfont.eot?v=4.2.0');
    src: url('/bitrix/templates/shop/css/../fonts/awesome/fontawesome-webfont.eot?#iefix&v=4.2.0') format('embedded-opentype'),
        url('/bitrix/templates/shop/css/../fonts/awesome/fontawesome-webfont.woff?v=4.2.0') format('woff'),
        url('/bitrix/templates/shop/css/../fonts/awesome/fontawesome-webfont.ttf?v=4.2.0') format('truetype'),
        url('/bitrix/templates/shop/css/../fonts/awesome/fontawesome-webfont.svg?v=4.2.0#fontawesomeregular') format('svg');
    font-weight: normal;
    font-style: normal;
}
*/

* {
    margin: 0;
    padding: 0;
    box-sizing: border-box;
    -webkit-box-sizing:border-box;
    -moz-box-sizing:border-box;
}
img {
    border: 0; /* 1 */
    -ms-interpolation-mode: bicubic; /* 2 */
    max-width: 100%;
    height: auto;
}
html, body {
    width: 100%;
    height: 100%;
        background-color: #f3f3f3;
}

body {
    font-family: 'Exo 2', sans-serif !important;
    font-size: 14px;
    color: #222;
}

.fa {
    display: inline-block;
    font-family: FontAwesome;
    font-style: normal;
    font-weight: normal;
    text-rendering: auto;
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
}

.fa.fa-times:before {
    content: '\f00d';
}

.fa.phone:before {
    content: '\f095';
}

.fa.mail:before {
    content: '\f0e0';
}

.fa.search:before {
    content: '\f002';
}

.fa.bars:before {
    content: '\f0c9';
}

.fa.th-large:before {
    content: '\f009';
}

.fa.th-list:before {
    content: '\f00b';
}

.fa.angle-down:before {
    content: '\f107';
}

.fa.angle-left:before {
    content: '\f104';
}

.fa.angle-right:before {
    content: '\f105';
}

.fa.fa-caret-down:before {
    content: '\f0d7';
    display: none;
}

.fa.caret-down:before {
    content: '\f0d7';
}

.fa.fa-caret-up:before {
    content: '\f0d8';
}


.fa.twitter:before {
    content: '\f099';
}

.fa.instagram:before {
    content: '\f16d';
}

.fa.facebook:before {
    content: '\f09a';
}

.fa.vk:before {
    content: '\f189';
}

.fa.fa-question-circle:before {
    content: '\f059';
}



.clear {
    clear: both;
}


a {
    color: #2f9c0e;
    text-decoration: none;
    border-bottom: 1px solid transparent;
    transition: all 0.2s ease-out;
}

a:hover {
    /*border-bottom-color: #0099d8;*/
}



.body-w {
    min-height: 100%;
    background-color: #f3f3f3;
}

/* HEADER */

.header {
    width: 100%;
}

.header__shop-line {
    position: relative;
    z-index: 2;
    line-height: 38px;
    background-color: #e2e2e2;
    border-bottom: 1px solid #bababa;
    text-align: right;
    padding: 0 60px;
    /*box-shadow: 0px -10px 20px 2px #000;*/
}

.header__shop-line__buttons {

}

.header__shop-line__button,
.header__shop-line__button--input {
    display: inline-block;
    border-left: 1px solid #bababa;
}

.header__shop-line__button-call {
    display: none;
}

.header__shop-line__button:last-child {
    border-right: 1px solid #f5f5f5;
}

.header__shop-line__button-a,
.header__shop-line__button__coupon {
    display: inline-block;
    padding: 0 28px;
    border-left: 1px solid #f5f5f5;
    border-bottom: none;
    color: #000;
}

.header__shop-line__button--input{
    vertical-align: top;
}

.header__shop-line__button__coupon{
    height: 38px;
    /*padding-top: 9px;*/
}

.header__shop-line__button__coupon__input{
    display: inline-block;
    border: none;
    border-bottom: 1px solid #0099d8;
    background-color: #e2e2e2;
    color: #0099d8;
    text-align: center;
    font-size: 11px;
    position: relative;

}

.header__shop-line__button__coupon__input--accepted{
    border-bottom: 1px solid #009c51;
    color: #009c51;
}

.header__shop-line__button__coupon__input::-webkit-input-placeholder{color:#2f9c0e;}
.header__shop-line__button__coupon__input::-moz-placeholder          {color:#2f9c0e;}/* Firefox 19+ */
.header__shop-line__button__coupon__input:-moz-placeholder           {color:#2f9c0e;}/* Firefox 18- */
.header__shop-line__button__coupon__input:-ms-input-placeholder      {color:#2f9c0e;}

.header__shop-line__button__coupon__input--accepted::-webkit-input-placeholder {color:#2f9c0e;}
.header__shop-line__button__coupon__input--accepted::-moz-placeholder {color:#2f9c0e;}/* Firefox 19+ */
.header__shop-line__button__coupon__input--accepted:-moz-placeholder {color:#2f9c0e;}/* Firefox 18- */
.header__shop-line__button__coupon__input--accepted:-ms-input-placeholder      {color:#2f9c0e;}

.header__shop-line__button-a-icon.icon-promo {
    background-image: url(http://static.highscreen.ru/img/icons/icon-promo_code.svg);
}


.header__shop-line__button:last-child .header__shop-line__button-a {
    border-right: 1px solid #bababa;
}

.header__shop-line__button-a:hover {
    border-bottom: none;
    color: #2f9c0e;
}

.header__shop-line__button-a-icon {
    display: inline-block;
    width: 18px;
    height: 18px;
    background-repeat: no-repeat;
    background-position: 50%;
    margin: 0 10px -4px 0;
}

.header__shop-line__button-a-icon.icon-enter {
    background-image: url('../data/images/header-door.png');
}

.header__shop-line__button-a-icon.icon-registr {
    background-image: url('../data/images/header-reg.png');
	margin-left: 10px;
}

.header__shop-line__button-a-icon.icon-cart {
    background-image: url('../data/images/header-cart.png');
}
#top_in_basket_total_items{
    background-color: #2f9c0e;
    color: #fff;
    border-radius: 12px;
    padding: 0;
    text-align: center;
    height: 20px;
    width: 20px;
    margin: 4px;
    line-height: 19px;
    display: inline-block;
}

.header_basket{
    /*text-decoration: underline !important;*/
    /*margin-right: 10px;*/
}

.header__info {
    /*  min-height: 86px;*/
    position: relative;
    z-index: 1;
    background-color: #fafafa;
    /*box-shadow: 0px -10px 20px 2px #000;*/
}

.header__info--content,.header__shop-line__buttons{
    width: 1170px;
    margin: 0 auto;
}

body.fixed .header__info {
    margin-bottom: 52px;
}

.header__info__logo-a{
    display: block;
    position: relative;
}
.header__info__logo {
    float: left;
    width: 180px;
    height: 36px;
    margin: 15px 0 25px 0;
    background-color: transparent;
    /*background-image: url(../data/images/logo.png);*/
    background-position: 0 50%;
    background-repeat: no-repeat;
    background-size: contain;
    color: rgb(0, 0, 0);
    font-family: 'Exo 2', sans-serif;
    font-size: 40px;
    text-align: center;
    font-weight: 500;
}


.header__info__logo_title{
    position: absolute;
    color: #666;
    line-height: 11px;
    font-size: 10.5px;
    top: 60px;
	left: 40px;
}

.header__info__hours,
.header__info__phones,
.header__info__ad {
    float: right;
}

.header__info__hours {
    line-height: 16px;
    margin: 27px 0 0 0;
    color: #989a9b;
    text-align: right;
    font-size: 12px;
}
.header__info__hours-text{
    margin-bottom: 13px;
    text-align: inherit;
	font-size: 13px;
	color: #989a9b;

}
.header__info__hours-call {
    font-size: 14px;
    font-weight: bold;
}

.header__info__phones {
    line-height: 24px;
    margin: 25px 30px 0 0;
    font-size: 18px;
    font-weight: bold;
    text-align: right;
}

.header__info__phone {
    white-space: nowrap;
    margin-bottom: 1px;
}

.header__info__phone-a {
    color: #333;
    border: none;
}

.header__info__ad {
    line-height: 24px;
    margin: 10px 50px 10px 0;
    font-size: 22px;
    text-align: center;
    width: 60%;
}

.header__info__ad-header {
    color: #0099d8;
    font-weight: 600;
}

.header__info__ad-des {
    color: #989a9b;
    font-size: 12px;
    margin-top: 0px;
}


.header__nav {
    /* height: 52px; */
    position: relative;
    width: 100%;
    background-color: #2f9c0e;
}
.header__nav-container{
    margin: 0 auto;
    width: 1243px;
}

body.fixed .header__nav {
    position: fixed;
    top: -52px;
    left: 0;
    z-index: 999;
    transition: all 0.3s ease-out;
}

.header__nav__mini-menu {
    display: none;
    float: left;
    line-height: 52px;
    margin: 0;
    padding: 0 10px;
    font-weight: bold;
    text-transform: uppercase;
    color: #fff;
    cursor: pointer;
}

.header__nav.active .header__nav__mini-menu,
.header__nav__mini-menu--hover {
    background-color: #44cb1a;
}

.header__nav__mini-menu-icon {
    margin: 0 10px 0 0;
}

.header__nav__menu {
    float: left;
    /*margin-left: -34px;*/
    /*margin: 0 0 0 60px;*/
}

.header__nav__menu-item {
    float: left;
    position: relative;
}

header__nav__menu-item-a parent:first-child{
    /*padding: 0;*/
}

.header__nav__menu-item-a-lev2,
.header__nav__menu-item-a {
    display: block;
    line-height: 52px;
    padding: 0 25px;
    white-space: nowrap;
    border: none;
}

.header__nav__menu-item-a.active {

}

.header__nav__menu-item:hover .header__nav__menu-item-a {
    background-color: #44cb1a;
}

.header__nav__menu-item-a-lev2:hover {
    background-color: #009adb;
}

.header__nav__menu-item-a-text-lev2,
.header__nav__menu-item-a-text {
    color: #fff;
    font-weight: 600;
    font-size: 16px;
    border-bottom: 1px solid transparent;
}

.header__nav__menu-item-a-lev2.active .header__nav__menu-item-a-text-lev2,
.header__nav__menu-item-a.active .header__nav__menu-item-a-text {
    border-bottom-color: #fff;
}

.header__nav__menu-items-lev2 {
    display: none;
    position: absolute;
    z-index: 10;
    top: 52px;
    left: 0;
    background-color: #00b3fa;
}

.header__nav__menu-item:hover .header__nav__menu-items-lev2 {
    display: block;
}


.header__nav__search {
    float: right;
    position: relative;
    width: 40px;
    height: 40px;
    line-height: 40px;
    margin: 6px 28px 6px 0;

    border: none;
    background-color: #2f9c0e;
    color: #fff;
    font-size: 16px;
    text-shadow: 1px 1px 1px #5f5f5f;
    cursor: pointer;

    text-align: center;
}

.header__nav__search form {
    display: none;
}

.header__nav__search.active form {
    display: block;
}

.header__nav__search__input-text-w {
    position: absolute;
    top: 0;
    right: 0;
}

.header__nav__search__input-text {
    width: 0;
    line-height: 40px;
    padding: 0 30px 0 10px;
    border: none;
    transition: width 0.1s ease-out;
	color: #000000;
}

.header__nav__search__input-submit-w {
    position: absolute;
    top: 0;
    right: 0;
}

.header__nav__search__input-submit {
    border: none;
    width: 40px;
    line-height: 40px;
    background-color: #44CB1A;

    font-size: 16px;
    text-shadow: 1px 1px 1px #5f5f5f;
    cursor: pointer;
}

.header__nav__search:hover .header__nav__search__input-submit {
    background-color: #44CB1A;
}

/* HEADER END */

.bx_page{
    padding: 3em 0;
}

/* SLIDER */


/* SLIDER END */



/* CONTENT */

.content {
    clear: both;
    padding: 20px 0;
    background-color: #f3f3f3;
}

.content.inpage {
    padding: 1em 60px;
    /*  background-color: #fff;*/
}

.slider-stock {
    margin: 0 auto;
    width: 1170px;
    padding-top: 10px;
}

.slider-stock__slider {
    position: relative;
    float: left;
    width: 774px;
    height: 376px;
    overflow: hidden;
}

.slider__items {
    position: absolute;
    top: 0;
    left: 0;
    width: 20000px;
    height: 100%;
    transition: left 0.3s ease-out;
}

.slider__item {
    float: left;
    width: 774px;
    height: 100%;
    background-position: 50%;
    background-repeat: no-repeat;
    background-size: contain;
}

.slider__nav-left,
.slider__nav-right,
.home-news__nav-left,
.home-news__nav-right {
    position: absolute;
    width: 50px;
    height: 100%;
    background-position: 20% 50%;
    background-repeat: no-repeat;
    background-image: url(/bitrix/templates/shop/css/../images/nav-left.png);
    cursor: pointer;
    top: 0;
    transition: all 0.2s ease-out;
}

.slider__nav-left:hover,
.slider__nav-right:hover,
.home-news__nav-left:hover,
.home-news__nav-right:hover{
    background-color: rgba(0, 0, 0, 0.1);
    background-position: 40% 50%;
}

.slider__nav-left
.home-news__nav-left {
    left: 0;
}

.slider__nav-right,
.home-news__nav-right {
    right: 0;
    -webkit-transform: rotate(180deg);
    -moz-transform: rotate(180deg);
    -o-transform: rotate(180deg);
    transform: rotate(180deg);
    filter: progid:DXImageTransform.Microsoft.BasicImage(rotation=2);

}
.slider-stock__slider .nav {
    position: absolute;
    bottom: 2%;
    left: 0;
    width: 100%;
    text-align: center;
}
.slider-stock__slider .nav ul li {
    display: inline-block;
    width: 8px;
    height: 8px;
    margin: 0 2px;
    border: 1px solid #fff;
    border-radius: 10px;
    cursor: pointer;
}
.slider-stock__slider .nav ul li:hover, .slider-stock__slider .nav ul li.active {
    background-color: rgba(255, 255, 255, 0.7);
}

.slider-stock__stock {
    float: left;
    width: 376px;
    margin: 0 0 0 20px;
}

.stock__item {
    position: relative;
    width: 374px;
    height: 76px;
    overflow: hidden;
    border: 1px solid #dadada;
    background-color: #f3f3f3;
    /*background-color: rgba(248, 197, 126, 0.6);*/
    margin-top: -1px;
    z-index: 1;
    transition: all 0.2s ease-out;
}

.stock__item:first-child {
    margin-top: 0;
}

.stock__item:hover {
    border: 1px solid #2f9c0e;
    z-index: 2;
}

.stock__item-image {
    position: relative;
    float: right;
    width: 50px;
    height: 50px;
    right: 10px;
    top: 13px;
    margin:0;
    overflow: hidden;
}

.stock__item-type {
  line-height: 30px;
      margin: 5px 0 0 5px;
      padding: 0 12px;
      padding-left: 50px;
      /*background-color: red;*/

      background: rgb(204,0,0);
      background: -moz-linear-gradient(top,  rgba(204,0,0,1) 0%, rgba(204,0,0,1) 100%);
      background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,rgba(204,0,0,1)), color-stop(100%,rgba(204,0,0,1)));
      background: -webkit-linear-gradient(top,  rgba(204,0,0,1) 0%,rgba(204,0,0,1) 100%);
      background: -o-linear-gradient(top,  rgba(204,0,0,1) 0%,rgba(204,0,0,1) 100%);
      background: -ms-linear-gradient(top,  rgba(204,0,0,1) 0%,rgba(204,0,0,1) 100%);
      background: linear-gradient(to bottom,  rgba(204,0,0,1) 0%,rgba(204,0,0,1) 100%);
      filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#cc0000', endColorstr='#cc0000',GradientType=0 );


      color: #fff;
      font-weight: bold;
      width: 120px;
      border-radius: 5px;
      position: relative;
            /*background-image: url('../data/images/circle.png');
      background-repeat: no-repeat;
      background-size: 25px 25px;*/
      /* float: left; */
      /* left: 80px; */
}

.stock__item-type-wrap {
  float: left;
  margin-right: 5px;
  margin-bottom: 50px;
      margin-top: 16px;
}

.stock__item-type::before {
  content: '';
  position: absolute;
  background-image: url('../data/images/circle.png');
  background-repeat: no-repeat;
  background-size: 25px 25px;
  top: 3px;
  left: 5px;
  /* margin-left: -8px; */
  width: 30px;
  height: 30px;
}
.stock__item-type::after {
  content: '';
  position: absolute;
  /* top: 100%; */
  left: 101px;
  margin-left: -8px;
  width: 30px;
  height: 30px;
  background-image: url('../data/images/triangle.png');
  background-repeat: no-repeat;
  background-size: 30px 30px;
  /*border-top: 15px solid transparent;
  border-bottom: 15px solid transparent;
  border-left: 15px solid #f00;
  */

}

/*.stock__item-type-wrap {
  line-height: 30px;
  padding: 30px 12px 0;
  background-color: #2f9c0e;
  color: #fff;
  font-weight: bold;
  width: 106px;
  height: 106px;
  position: absolute;
  text-align: center;
  line-height: 20px;
  border-radius: 50%;
  top: 5px;
  left: 10px;
  z-index: 1000;

}

.stock__item-type {
  line-height: 30px;
  padding: 30px 12px 0;
  background-color: #D9FF01;
  color: #2F9C0E;
  font-weight: bold;
  width: 100px;
  height: 100px;
  position: absolute;
  text-align: center;
  line-height: 20px;
  border-radius: 50%;
  border: 3px solid #fff;
  transform: rotate(-15deg);
  top: 3px;
  left: 3px;
  z-index: 1000;
}*/

.stock_item-stripe {
  position: absolute;
  width: 180px;
  height: 19px;
  background-color: #44cb1a;
  color: #fff;
  text-align: center;
  transform: rotate(-45deg);
  z-index: 2000;
  left: -57px;
  top: 20px;
  padding: 0 50px;
}

.stock__item-title {
  /* margin: 20px 120px 0 130px; */
  /*margin: 5px 65px 0 30px;*/
  text-transform: uppercase;
  color: #000;
  font-weight: 500;
  font-size: 11.5px;
  /*margin-left: 15px;*/
  display: table-cell;
  vertical-align: middle;
  height: 76px;
  padding: 5px 20px 0 0;
  overflow: hidden;
text-overflow: ellipsis;
}

.stock__item-des {
    margin: 6px 120px 0 25px;
    color: #989a9b;
    font-size: 12px;
}


.home-catalog-types {
    clear: both;
    margin: 20px auto 0;
    width: 1170px;
}

.catalog-types__item {
    float: left;
    position: relative;
    width: 376px;
    height: 200px;
    margin: 0 21px 0 0;
}

.catalog-types__item:last-child {
    margin: 0;
}

.catalog-types__item-image {
    position: absolute;
    top: 0;
    left: 0;
    width: 100%;
    height: 200px;
    background-color: #fff;
    background-position: 50%;
    background-repeat: no-repeat;
    background-size: cover;
}

.catalog-types__item-text {
    position: absolute;
    bottom: 0;
    left: 0;
    width: 100%;
    padding: 10px 0;
    text-align: center;
    color: #333;
    background-color: rgba(256,256,256,0.7);
    transition: all 0.3s ease-out;
}

.catalog-types__item:hover .catalog-types__item-text {
    color: #fff;
    background-color: #2f9c0e;
}

.catalog-types__item-title {
    font-size: 22px;
    text-transform: uppercase;
}

.breadcrumbsholder {
    /*padding: 30px 0;*/
    padding: 0px 0 0 0;
}
.breadcrumbsholder > * {
    float: left;
}
.breadcrumbsholder > .share {
    float: right;
    margin-top: -5px;
}

.home-news {
    clear: both;
    position: relative;
    margin: 20px auto 0;
    width: 1170px;
    background-color: #fff;
    border: 1px solid #dadada;
}

.home-news__title {
    line-height: 70px;
    text-align: center;
    text-transform: uppercase;
    font-weight: 100;
    font-size: 20px;
    color: #000;
}

.home-news__items {
    position: relative;
    width: 1060px;
    height: 288px;
    margin: 0 auto;
    overflow: hidden;
}

.home-news__items-w {
    position: absolute;
    top: 0;
    left: 0;
    width: 20000px;
    height: 100%;
    transition: left 0.3s ease-out;
}

.home-news__item {
    position: relative;
    float: left;
    width: 250px;
    height: 288px;
    margin: 0 20px 0 0;
    overflow: hidden;
}

.home-news__item-image {
    width: 100%;
    height: 160px;
    background-position: 50%;
    background-repeat: no-repeat;
    /*background-size: contain;*/
}

.home-news__item-title {
    margin: 16px 0 0 0;
}

.home-news__item-title-text {
    font-size: 16px;
    color: #333;
    /*  border-bottom: 1px solid transparent;*/
    transition: all 0.3s ease-out;
}

.home-news__item-a:hover .home-news__item-title-text {
    color: #009adb;
    border-bottom-color: #009adb
}

.home-news__item-date {
    position: absolute;
    bottom: 0;
    left: 0;
    width: 100%;
    padding: 6px 0 14px 0;
    background-color: #fff;
    font-size: 1.2em;
}

.home-news__item-date-text {
    display: inline-block;
    padding: 16px 0 0 0;
    /*
      color: #009adb;
    */
    color: #1c98e0;
    border-top: 1px solid #d5d5d5;
}

.home-text {
    clear: both;
    margin: 20px auto 0;
    width: 1170px;
    color: #626262;
}


/*
.catalogue.clearfix {
  padding: 0 60px;
}

.catalogue ASIDE {
  background-color: #fff;
}
*/


/* CONTENT END */



/* breadcrumbs */

.breadcrumbs__wrap {
    width: 100%;
    border-bottom: 1px solid #dddddd;
    background-color: #f3f3f3;
}

.breadcrumbs {
    line-height: 30px;
    padding: 0 60px;
    background-color: #f3f3f3;
    border-bottom: 1px solid #dddddd;
}

@media (max-width: 1220px){
    .breadcrumbs {
        width: 950px;
    }
}

.breadcrumbs__item {
    color: #626262;
    font-size: 12px;
    margin: 0 6px;
}

.breadcrumbs__item-a {
    color: #626262;
    border: none;
}

.breadcrumbs__item-a:hover {
    color: #262626;
    border-bottom: 1px solid #262626;
}

/* breadcrumbs END */



/* CATALOG */

.catalog {
    position: relative;
}

.catalog__column-left {
    position: relative;
    float: left;
    width: 200px;
}

.catalog__column-left__open {
    display: none;
    position: absolute;
    top: 20px;
    left: 100%;
    line-height: 30px;
    background-color: #2F9C0E;
    color: #fff;
    padding: 0 20px;
    font-size: 12px;
    white-space: nowrap;
    cursor: pointer;
}

.catalog__column-left__open-text {
    margin: 0 0 0 6px;
    text-transform: uppercase;
    font-weight: bold;
}



.catalog__column-right {
    margin: 0 0 0 200px;
    padding: 0 0 30px;
}

.catalog__column__title {
    padding: 20px 10px;
    border-bottom: 1px solid #ddd;
    text-transform: uppercase;
}

.catalog__column__title-h {
    font-size: 20px;
}

.catalog__column__title-d {

}

.catalog__column__left-menu__item-a {
    display: block;
    line-height: 20px;
    padding: 10px;
    color: #222;
    border: none;
    border-bottom: 1px solid #ddd;
    font-size: 14px;
}

.catalog__column__left-menu__item-a:hover {
    background-color: #ececec;
    border-bottom: 1px solid #ddd;
}

.catalog__column__left-menu__item-a.active {
    color: #0099d8;
    font-weight: bold;
}


.catalog__filters {
    padding: 0;
    background-color: #fff;
    border-bottom: 1px solid #ddd;
    border-right: 1px solid #ddd;
    border-left: 1px solid #ddd;
	height: 140px;
}

.catalog__filter__column.right {
    float: right;
}

.catalog__filter {
    float: left;
}

.catalog__filter-title {
    float: left;
    line-height: 46px;
    color: #8c8c8c;
}
.catalog__filter-title--highlight{
    color: #009adb;
}
.catalog__filter-val {
    float: left;
}

.catalog__filter-list {
    position: relative;
    display: inline-block;
    line-height: 24px;
    margin: 10px 0 10px 10px;
    background-color: #fff;
    border: 1px solid #ddd;
    border-radius: 4px;
    cursor: pointer;
}

.catalog__filter-list.device,
.catalog__filter-list.device:hover .catalog__filter-list__items {
    min-width: 155px;
}

.catalog__item__label:after {
    content: '';
    position: absolute;
    right: 10px;
    top: 37px;
    text-align: center;
    /*    line-height: 19px;
        height: 17px;*/
    padding: 3px;
    width: 58px;
    font-weight: bold;
    font-family: 'Exo 2';
    text-transform: uppercase;
    color: #fff;
    background-color: #1b98e0;
    font-size: 12px;
    /*z-index: 10;*/
}

.catalog__item__label--action:after {
    content: 'Акция';
    background-color: #fc7d00;
    background: url('http://static.highscreen.ru/img/1x1_fc7d00-70.png') repeat;
}
.catalog__item__label--hit:after {
    content: 'Хит';
    background-color: #fc7d00;
    background: url('http://static.highscreen.ru/img/1x1_fc7d00-70.png') repeat;
}
.catalog__item__label--new:after {
    content: 'Новинка';
    background: url('http://static.highscreen.ru/img/1x1_1b98e0-70.png') repeat;
}
.catalog__item--with_gift:after {
    content: '';
    background: url('http://static.highscreen.ru/img/icons/gift_icon.svg') no-repeat;
    position: absolute;
    right: 10%;
    top: 33px;
    width: 25px;
    height: 25px;
    z-index: 10;
}

.catalog__items.list .catalog__item--with_gift:after{
    right: inherit;
    /*left: 153px;*/
    top: 10px;
}

.catalog__items.list  .catalog__item__label:after,
.catalog__items.list .catalog__item--with_gift:after{
    right: -13%;
    top: 19px;
}

.catalog__items.list .catalog__item__label:after,
.catalog__items.list .catalog__item--with_gift:after{
    right: -21px;
    top: 20px;
}

.catalog__filter-list-select {
    padding: 0 28px 0 10px;
}

.catalog__filter-list-select-icon {
    position: absolute;
    right: 6px;
    top: 0;
}

.catalog__filter-list__items {
    display: none;
}

.catalog__filter-list--hover {
    border-color: #fff;
    z-index: 20;
}

.catalog__filter-list--hover .catalog__filter-list__items {
    display: block;
    position: absolute;
    top: -1px;
    left: -1px;
    z-index: 9;
    background-color: #fff;
    border: 1px solid #ddd;
    border-radius: 4px;
}

.catalog__filter-list__item-a {
    position: relative;
    white-space: nowrap;
    display: block;
    padding: 0 28px 0 10px;
    line-height: 24px;
    color: #8c8c8c;
    border-bottom: 1px solid #ddd;
}

.catalog__filter-list__item-a:hover,
.catalog__filter-list__item-a.active {
    border-bottom: 1px solid #ddd;
    color: #222;
}

.catalog__filter-list__item-a.active {
    font-weight: bold;
}

.catalog__filter-list__item:last-child .catalog__filter-list__item-a {
    border: none;
}


.catalog__filter-types {
    margin: 0 0 0 10px;
}

.catalog__filter-types__item {
    float: left;
    width: 24px;
    line-height: 24px;
    border: 1px solid #ddd;
    border-radius: 4px;
    margin: 10px 0 10px 10px;
    text-align: center;
    color: #8c8c8c;
    cursor: pointer;
}

.catalog__filter-types__item.active,
.catalog__filter-types__item:hover {
    border-color: #009adb;
    background-color: #009adb;
    color: #fff;
}


.catalog__filter__device {

}

.catalog__filter__device__item {
    display: inline-block;
    width: 150px;
    margin: 10px;
    padding: 10px;
    vertical-align: top;
    text-align: center;
    cursor: pointer;
    border: 1px solid #fff;
    transition: border 0.3s ease-out;
}

.catalog__filter__device__item.active,
.catalog__filter__device__item:hover {
    border-color: #009adb;
}

.catalog__filter__device__item-image {
    width: 130px;
    height: 60px;
    background-position: 50%;
    background-repeat: no-repeat;
    background-size: contain;
}

.catalog__filter__device__item-title {
    margin: 10px 0 0;
}

.catalog__filter__device__item-title-a {

}


.catalog__items {
    border-left: 1px solid #ddd;
}

.catalog__items-w {
    background-color: #fff;
}

.catalog__items-w.hidden {
    display: none;
}

.catalog__items-w__title {
    padding: 20px;
    font-weight: normal;
}

.catalog__item {
    float: left;
    width: 20%;
}

.catalog__item.hidden {
    display: none;
}

.catalog__items.list .catalog__item {
    float: none;
    width: 100%;
}

.catalog__item-w {
    height: 380px;
    padding: 20px;
    background-color: #fff;
    margin: -1px 0 0 -2px;
    overflow: hidden;
    border: 1px solid #ddd;
    /*position: relative;*/
}

.catalog__item-w:hover {
    position: relative;
    z-index: 10;
    border-color: #2f9c0e;
}

.catalog__items.list .catalog__item-w {
    height: auto;
}

.catalog__items.list .catalog__item__image-w {
    float: left;
    position: relative;
}

.catalog__item__image {
    width: 100%;
    height: 180px;
    background-position: 50%;
    background-repeat: no-repeat;
    background-size: contain;
}

.catalog__items.list .catalog__item__image {
    width: 150px;
    margin: 0 auto;
}


.catalog__items.list .catalog__item__title-w {
    float: left;
    width: 450px;
    margin: 0 0 0 40px;
}

/*.catalog__items.list .products_name-free_delivery_label--catalog{*/
.products_name-free_delivery_label--catalog{
    display: none;
}

.catalog__item__des-comments{
    height: 12px;
}

.catalog__item__des-color{
    height: 16px;
}
.catalog__item__title {
    height: 60px;
    /*margin: 3px 0 11px;*/
    margin: 0;
    margin-top: 3px;
    text-align: center;
    overflow: hidden;
    font-size: 16px;
}

.catalog__items.list .catalog__item__title {
    min-height: 0;
    /*font-size: 16px;*/
    text-align: left;
    height: inherit;
}

.catalog__item__title-a {
    color: #222;
}

.catalog__item-w:hover .catalog__item__title-a {
    color: #2f9c0e;
}

.catalog__item__preview {
    display: none;
    color: #8c8c8c;
}

.catalog__items.list .catalog__item__preview {
    display: block;
    font-size: 14px;
}


.catalog__items.list .catalog__item__des-w {
    float: right;
    width: 200px;
}

.catalog__item__des {
    margin: 10px 0 0;
}

.catalog__item__des__column {
    float: left;
    width: 50%;
    position: relative;
}

.catalog__item__des-info {
    font-size: 12px;
    color: #8c8c8c;
}

.catalog__item__des-info--empty{
    height: 14px;
	text-overflow: ellipsis;
	-o-text-overflow: ellipsis;
	overflow:hidden;

}

.catalog__item__des-oldprice,
.catalog__item__des-price {
    text-align: left;
}
.catalog__item__des-oldprice,
.catalog__item__des-price {
    white-space: nowrap;
}
.catalog__item__des-oldprice {
    position: absolute;
    top: -21px;
    left: 0;
    right: 0;
}

.catalog__item__des-oldprice-text {
    color: #8c8c8c;
    text-decoration: line-through;
    font-size: 18px;
}

.catalog__item__des-price {
    font-size: 14px;
}


.catalog__item__des__buttons {
    text-align: right;
}

.catalog__item__des__button {
    margin: 0 0 6px;
}

.catalog__item__des__to-cart,
.catalog__item__des__add-cart {
    display: inline-block;
    line-height: 24px;
    padding: 0 14px;
    background-color: #2f9c0e;
    color: #fff;
    border-radius: 4px;
    border: none;
    white-space: nowrap;
    transition: background 0.3s ease-out;
}

.catalog__item__des__to-cart.catalog__item__des__add-cart{
    background-color: #2f9c0e;
}

.catalog__item__des__to-cart:not(.touch):hover {
    background-color: #39C883;
}

.catalog__item__des__add-cart {
    background-color: #2f9c0e;

}

.catalog__item__des__add-cart:not(.touch):hover {
    background-color: #44cb1a;
}

.catalog__item__des__fast-buy {
    border-bottom-color: #009adb;
    white-space: nowrap;
}

.catalog__item__des-coments{
    text-decoration: underline;
    color:inherit;
}
.catalog_section_bottom_text{
    margin-top: 10pt;
    color: #000;
    font-size: 10pt;
    text-align: justify;
}
.go2compare {
    white-space: nowrap;
}


/* CATALOG END */



/* FOOTER */

.footer-body-fix {
    height: 280px;
        background-color: #f3f3f3;
}

.footer {
    clear: both;
    background-color: #2f9c0e;
    margin: 0;
    margin-top: -280px;
    padding: 20px 0;
    color: #fff;
    font-size: 12px;
}

.footer-w {
    width: 1170px;
    margin: 0 auto;
}

.footer__title {
    text-transform: uppercase;
    font-size: 16px;
    font-weight: 500;
}


.footer__info,
.footer__about,
.footer__contacts {
    float: left;
    min-height: 240px;
}


.footer__info {
    max-width: 340px;
    padding: 0 20px 0 0;
    border-right: 1px solid #fff;
}

.footer__info__nav {
    margin: 20px 0 0;
}

.footer__info__nav-column {
    float: left;
}

.footer__info__nav-column:first-child {
    margin: 0 60px 0 0;
}

.footer__info__nav-item-a {
    line-height: 24px;
}

.footer__info__nav-item-a-text {
    color: #fff;
    border-bottom: 1px solid transparent;
    transition: border 0.3s ease-out;
}

.footer__info__nav-item-a:hover .footer__info__nav-item-a-text,
.footer__info__nav-item-a.active .footer__info__nav-item-a-text {
    border-bottom-color: #fff;
}


.footer__info__error {
    margin: 20px 0 0 0;
    color: #85cbea;
}

.footer__info__error-text {
    display: inline-block;
    padding: 10px;
    background-color: #0084bc;
    border: 1px solid #3bb9e4;
    color: #85cbea;
}


.footer__about {
    max-width: 480px;
    margin: 0 0 0 20px;
    padding: 0 20px 0 0;
    border-right: 1px solid #fff;
}

.footer__about__text {
    line-height: 20px;
    margin: 20px 0 0;
}


.footer__contacts {
    margin: 0 0 0 20px;
    padding: 0;
}

.footer__contacts__adres {
    margin: 20px 0 0;
}

.footer__contacts__adres-icon,
.footer__contacts__phones-icon,
.footer__contacts__mails-icon {
    display: inline-block;
    width: 20px;
    height: 20px;
    margin: 0 10px -6px 0;
    background-repeat: no-repeat;
    background-position: 50%;
}

.footer__contacts__adres-icon {
    background-image: url('/bitrix/templates/shop/css/../images/footer-adres.png');
}

.footer__contacts__phones-icon {
    background-image: url('/bitrix/templates/shop/css/../images/footer-phone.png');
}

.footer__contacts__mails-icon {
    background-image: url('/bitrix/templates/shop/css/../images/footer-mail.png');
}

.footer__contacts__phones,
.footer__contacts__mails {
    margin: 20px 0 0;
}

.footer__contacts__phone,
.footer__contacts__mail {
    display: inline-block;
    width: 130px;
    border-right: 1px solid #fff;
    white-space: nowrap;
}

.footer__contacts__mail--bold{
    text-decoration: underline;
    font-weight: bold;
}

.footer__contacts__phone:last-child,
.footer__contacts__mail:last-child {
    margin: 0 0 0 0px;
    border-right: none;
}

.footer__contacts__phone-a,
.footer__contacts__mail-a {
    color: #fff;
}

.footer__contacts__phone-a:hover,
.footer__contacts__mail-a:hover {
    border-color: #fff;
}


.footer__title-social {
    margin: 20px 0 0;
}


.footer__contacts__social {
    float: left;
    margin: 20px 0 0;
}

.footer__contacts__social__item {
    display: inline-block;
    width: 24px;
    height: 24px;
    margin: 0 10px 0 0;
    border: 1px solid #3bb9e4;
    border-radius: 4px;
    background-position: 50%;
    background-repeat: no-repeat;
}

.footer__contacts__social__item:hover {
    border-color: #fff;
}


.footer__contacts__social__item.icon-facebook {
    background-image: url('/bitrix/templates/shop/css/../images/footer-facebook.png');
}

.footer__contacts__social__item.icon-twitter {
    background-image: url('/bitrix/templates/shop/css/../images/footer-twitter.png');
}

.footer__contacts__social__item.icon-vk {
    background-image: url('/bitrix/templates/shop/css/../images/footer-vk.png');
}

.footer__contacts__social__item.icon-instagram {
    background-image: url('/bitrix/templates/shop/css/../images/footer-instagram.png');
}

.footer__contacts__social__item.icon-ok {
    background-image: url('/bitrix/templates/shop/css/../images/footer-ok.png');
}


.footer__contacts__ya-market {
    float: right;
    width: 88px;
    height: 30px;
    margin: 15px 0 0;
    background-color: #fff;
}

/* FOOTER END */

.explan H1 {
    font-family: 'Russo One', sans-serif;
    font-size: 36px;
    font-weight: 400;
    line-height: 1.1;
    display: inline;
}

#acc_original-container .buttons--hide{
    display: none;
}
.label_23feb,.label_23feb--cart{
    position: absolute;
    right: 10px;
    top: 63px;
    text-align: center;
    padding: 3px;
    width: 64px;
    height: 40px;
    background-image: url(/img/23feb_64.jpg);
    color: #fff;
    background-color: #1b98e0;
    display: block;
    z-index: 10;
}

.label_23feb--cart{
    right: 0px;
    top: 37px;
}

.catalog__items.list .label_23feb{
    right: -21px;
    top: 48px;
}

#catalog__filter-types__item__delimeter{
    height: 46px;
    width: 1px;
}

/* hs-modal */
.hs-modal {
    background-color: #fff;
    border-radius: 2px;
    position: relative;
    display: none;
    text-align: left;
    z-index: 999;
}

.hs-modal__window {
    background-color: #fff;
    border-radius: 2px;
    padding: 0 0 10px;
}

.hs-modal__window__top {
    position: relative;
    background-color: #009adb;
    color: #fff;
    font-weight: bold;
    padding: 5px 10px;
}

.hs-modal__window__top-a {
    position: absolute;
    top: 5px;
    right: 10px;
    color: #fff;
}

.hs-modal__window__input {
    margin: 10px 0 0;
}

.hs-modal__window__input-label {
    display: inline-block;
    width: 70px;
    text-align: right;
    color: #000;
}

.hs-modal__window__input-html {
    display: inline-block;
    margin: 0 0 0 10px;
}

.hs-modal__window__href,
.hs-modal__window__error {
    margin: 10px 0 0 80px;
    color: #000;
}

.hs-modal__window__error {
    display: none;
    color: #f00;
}

.hs-modal__window__buttons {
    margin: 16px 0 0 80px;
}

.hs-modal__window__button-enter,
.hs-modal__window__button-cancel {
    display: inline-block;
    line-height: 20px;
    padding: 0 10px;
    border: 1px solid #A9A9A9;
    border-radius: 4px;
    color: #000;
    font-weight: bold;
    cursor:pointer;
}

.hs-modal__window__button-cancel:hover {
    border-color: #009adb;
    color: #009adb;
}

.hs-modal__window__button-enter {
    background-color: #009adb;
    border-color: #0085BD;
    color: #fff;
    margin: 0 30px 0 0;
}

.hs-modal__window__button-enter:hover {
    background-color: #00b3fa;
    border-color: #009adb;
}

.article_content--default p{
    margin: 1em 0;
    text-align: justify;
    font-size: 13px;
}
.article_pic_default{
    width: 700px;
}

.article_list--default{
    list-style:disc;
    margin-left: 2em;
    font-size: 13px;
}
ol.article_list--default{
    list-style:decimal;
}

/* REVIEWS BEGIN */


.item-reviews {
    position: relative;
    padding: 0 0 40px 0;
}

.item-reviews__title {
    line-height: 30px;
    margin: 40px 0 0 60px;
    font-size: 18px;
}


.item-reviews__add-w {
    padding: 0 38px;
}


.item-reviews__add-a {
    position: absolute;
    display: inline-block;
    top: 0;
    right: 40px;
    line-height: 30px;
    padding: 0 16px;
    color: #fff;
    background-color: #0099d8;
    border-radius: 4px;
    border: none;
}

.item-reviews__view {
    display: none;
    padding: 38px 0 0;
    border: 1px solid #e5e6e7;
}

.reviews-post__title,
.reviews-post__user,
.reviews-post__back,
.reviews-post__content {
    margin: 0 38px 20px;
}

.reviews-post__title {
    font-size: 24px;
}

.reviews-post__content {
    background-color: #fff;
    margin: 0 20px 20px;
    padding: 18px;
}
.reviews-post__content__video{
    margin: 0 auto;
    width: 500px;
}

.reviews__button__submit {
    display: inline-block;
    font-family: 'Exo 2', sans-serif;
    font-size: 14px;
    color: #fff;
    background-color: #009adb;
    padding: 0 6px;
    line-height: 28px;
    border-radius: 4px;
    border: none;
    cursor: pointer;
    -webkit-transition: background-color 0.3s, color 0.3s;
    -moz-transition: background-color 0.3s, color 0.3s;
    -ms-transition: background-color 0.3s, color 0.3s;
    -o-transition: background-color 0.3s, color 0.3s;
    transition: background-color 0.3s, color 0.3s;
}


div.blog-post-edit-form,
div.blog-comment-fields {
    background-color: #F7F8F9;
    padding: 0;
}


.reviews__blog-post-edit {
    display: none;
}

.reviews__blog-post-edit.active {
    display: block;
}

.item-reviews__add__list__select__item-remove {
    margin: 0 10px 0 3px;
    color: red;
    cursor: pointer;
}
.blog-post-delete-link{
    cursor: pointer;
    text-decoration: underline;
    color: #0099d8;
}
.reviews__add__input {
    margin: 10px 0;
}

.reviews__add__input input,
.reviews__add__input textarea {
    width: 300px;
}

.reviews__add__input textarea {
    height: 100px;
}

.reviews__add__input-title {
    display: inline-block;
    width: 180px;
}


.reviews__type-video textarea {
    width: 480px;
    height: 100px;
}



.item-reviews__add__list__items-w {
    display: inline-block;
    position: relative;
}

.item-reviews__add__list__items {
    display: none;
    position: absolute;
    top: 31px;
    left: 0;
    width: 300px;
    height: 300px;
    padding: 0;
    background-color: #fff;
    overflow: auto;
    border: 1px solid #eee;
    border-radius: 4px;
}

/*.item-reviews__add__list__items-w:hover .item-reviews__add__list__items,*/
.item-reviews__add__list__items.active {
    display: block;
}

.item-reviews__add__list__item {
    padding: 10px 20px;
    cursor: pointer;
}

.item-reviews__add__list__item.active {
    font-weight: bold;
}

.item-reviews__add__list__item:hover {
    background-color: #f4f4f4;
}

.item-reviews__add__list__items-text {
    position: relative;
    display: inline-block;
    line-height: 30px;
    padding: 0 40px 0 20px;
    background-color: #fff;
    border: 1px solid #eee;
    border-radius: 4px;
    cursor: pointer;
}

.item-reviews__add__list__items-text-i {
    position: absolute;
    top: 0;
    right: 0;
    width: 20px;
    text-align: center;
    border-left: 1px solid #eee;
}

.blog-edit-editor-area .reviews__type-video,
.blog-edit-editor-area .reviews__type-text {
    display: none;
}

.blog-edit-editor-area.active .blog-comment-field-bbcode {
    display: block;
}

.blog-edit-editor-area.active .reviews__open__blog-edit-editor-area.open-1 {
    display: none;
}


.item-reviews__items {
    padding: 0 41px;
}

.reviews__item {
    float: left;
    width: 322px;
    margin: 38px 19px 0;
}

.reviews__item-title {
    overflow: hidden;
    height: 34px;
}

.reviews__item-ptext {
    overflow: hidden;
    height: 194px;
    margin: 5px 0 0;
    padding: 5px;
    background-color: #eee;
    display: block;
    color: #111;
    text-decoration: none;
    background-size: cover;
    background-position: 50%;
}
.reviews__item-ptext:hover{
    /*    outline: 1px solid #ccc;*/
    background-color: #0099d8;
    color: #fff;
}
.reviews__item-source {
    line-height: 40px;
    border-bottom: 1px solid #d8d8d8;
    background-color: #f3f3f3;
    text-align: center;
    font-size: 14px;
}

.reviews__item-date-link {
    line-height: 40px;
    background-color: #f3f3f3;
    text-align: center;
    font-size: 14px;
    position: relative;
    min-height: 40px;
}

.reviews__item-date {
    position: absolute;
    left: 16px;
}

.reviews__item-link {
    position: absolute;
    right: 16px;
}



.reviews-post {

}
.reviews__not-login__msg {
    margin-top: 1em;
}
/* REVIEWS END */
/* End */



/* Start:/bitrix/templates/shop/css/media.css*/
@media (max-width: 1600px) {

    .catalog__item {
        width: 25%;
    }

}


@media (max-width: 1350px) {

    .catalog__item {
        width: 50%;
    }

}

@media (max-width: 1220px) {

    .slider-stock,
    .home-catalog-types,
    .home-text,
    .footer-w {
        width: 940px;
    }

    .header__nav-container{
        width: 962px;
    }
    .header__info__ad{
        margin: 23px 21px 0 0;
    }

    .header__nav__menu-item-a-lev2, .header__nav__menu-item-a {
        padding: 0 20px;
    }
    .home-news,.header__info--content,.header__shop-line__buttons {
        width: 938px;
    }
    .header__nav__search{
        margin: 6px 4px 6px 0;
    }
    .slider-stock__slider,
    .slider__item {
        width: 620px;
    }

    .slider-stock__stock {
        width: 300px;
    }

    .stock__item {
        width: 298px;
    }

    .stock__item-image {
        width: 100px;
    }

    .stock__item-title {
            margin: 20px 120px 0 130px;
    }

    .stock__item-des {
        margin: 6px 100px 0 25px;
    }

    .catalog-types__item {
        width: 299px;
    }

    .home-news__items {
        width: 860px;
    }

    .home-news__item {
        width: 200px;
    }

    .footer-body-fix {
        height: 320px;
    }

    .footer {
        margin-top: -320px;
    }

    .footer__info, .footer__about, .footer__contacts {
        min-height: 280px;
    }

    .footer__info {
        width: 250px;
    }
    .footer__info__nav-column{
        float: none;
    }
    .footer__about {
        width: 340px;
    }


    .reviews__item {
      width: 248px;
}


}

@media (max-width: 1200px) {

    .header__shop-line {
        padding: 0 10px;
    }

    .header__info__logo {
        margin: 25px 0 25px 10px;
    }
    .header__info__logo_title{
        font-size: 10px;
        left: 20px;
        top: 70px;
    }
    .header__info__hours
    {
        margin: 25px 10px 0 0;
    }
    .header__nav__menu {
        margin: 0 0 0 10px;
    }

    .header__nav__search {
        margin: 6px 10px 6px 0;
    }

    .content.inpage {
        padding: 0 10px;
    }

}





@media (max-width: 1130px) {

    .header__nav__menu-item-a-lev2,
    .header__nav__menu-item-a {
        padding: 0 20px
    }

    .header__nav__menu-item-a-text-lev2,
    .header__nav__menu-item-a-text {
        font-size: 14px;
    }
    .header__nav-container{
        width: 972px;
    }
    .catalog__item {
        /*    width: 33%;*/
    }

    .catalog__items.list .catalog__item__title-w {
        width: 300px;
        margin: 0 0 0 20px;
    }

}


@media (max-width: 960px) {

    .header__nav__menu,
    .header__info__hours {
        display: none;
    }

    .header__nav.active .header__nav__menu,
    .header__nav__mini-menu {
        display: block;
    }
    .header__nav-container{
        width: 100%;
    }
    .header__shop-line__button-call {
        display: inline-block;
    }
    .header__info--content,.header__shop-line__buttons{
        width: 100%;
    }
    .header__nav__menu {
        position: absolute;
        top: 52px;
        left: 0;
        background: #2f9c0e;
        margin: 0;
        z-index: 111;
    }

    .header__nav__menu-item {
        float: none;
    }

    .header__nav__menu-items-lev2 {
        top: 0;
        left: 100%;
    }
    .header__nav__menu-item-a-text{
        width: 100%;
        display: block;
    }
    .slider-stock,
    .home-catalog-types,
    .home-text,
    .footer-w,
    .home-news,
    .slider-stock__slider,
    .slider__item,
    .slider-stock__stock,
    .catalog-types__item {
        width: 480px;
    }
    .slider__item__buy{
        display: none;
    }
    .slider-stock__slider,
    .slider-stock__stock {
        float: none;
        margin: 0 auto;
    }

    .slider-stock__slider {
        height: 200px;
    }

    .slider-stock__stock {
        margin: 20px 0 0;
    }

    .stock__item {
        width: 478px;
    }

    .home-news__items {
        width: 420px;
        height: 576px;
    }

    .home-news__items-column {
        float: left;
        width: 440px;
    }

    .slider__nav-left,
    .slider__nav-right,
    .home-news__nav-left,
    .home-news__nav-right {
        width: 24px;
    }

    .item-reviews__title {
      margin: 20px;
    }

    .item-reviews__add-a {
      right: 20px;
    }

    .item-reviews__items {
      padding: 0 3px 0 8px;
    }

    .reviews__item {
      width: 218px;
      margin: 20px 7px 0;
    }


    .footer-body-fix {
        height: 550px;
    }

    .footer {
        margin-top: -539px;
    }
    .footer__about{
        display: none;
    }
    .footer__info,
    .footer__contacts {
        float: none;
        border: none;
        width: initial;
        max-width: initial;
        min-height: initial;
        margin: 0 0 40px 0;
        padding: 0;
    }

    .catalog__item {
        width: 50%;
    }

}


@media (max-width: 920px) {

    .catalog__items.list .catalog__item__preview {
        display: none;
    }

}
@media (max-width: 800px) {
    .header__info__phones{
        margin: 19px 20px 0 0;
    }
}

@media (max-width: 790px) {
    .header__info__logo_title{
        display: none;
    }
    .catalog__column-left {
        /* float: none;
        position: absolute;
		left: -210px;*/
		/*float: left;
        top: 0;

        background-color: #f3f3f3;
        z-index: 110;
        transition: left 0.3s ease-out;*/
        float: none;
        position: absolute;
        top: 0;
        left: -210px;
        background-color: #f3f3f3;
        z-index: 110;
        transition: left 0.3s ease-out;
    }

    .catalog__column-left--opened {
        left: 0;
    }

    .catalog__column-left__open {
        display: block;
    }

    .catalog__column-right {
        margin: 0;
        padding-top: 6em;
    }

    .catalog__items.list .catalog__item__preview {
        display: block;
    }
    .breadcrumbs{
        padding: 0 1em;
    }
    .section_name,.catalog_section_bottom_text,.scrollup{
        display:none;
    }
    .scrollup{
        display:none !important;
    }

    .catalog__items.list .catalog__item__des__column--hidemobile{
        display:none;
    }
}


@media (max-width: 740px) {

    .header__shop-line__button-a {
        padding: 0 8px;
    }

    .header__info__logo {
        margin: 0px 10px;
        width: 100%;
        height: 100%
    }

    .header__info__phones,
    .header__info__ad {
        float: none;
        margin: 0 10px 0 0;
        text-align: center;
    }

    .header__info__phones{
        padding-top: 5px;
    }

    .header__info__ad {
        clear: both;
        text-align: center;
        padding: 0 0 4px;
        line-height: 11px;
        font-size: 11px;
        margin: 0;
            width: 100%;
    }

    .header__info__phone {
        display: inline;
        margin: 0 10px 0 0;
        font-size: 13px;
    }
    .header__info__ad-header,.header__info__phone-a,.header__info__ad-des{
        display: inline;
    }
    .header__info__ad-header{
        font-size: 15px;
    }
    .header__info__phone-a{

    }

}


@media (max-width: 720px) {

    .catalog__items.list .catalog__item__des-w {
        width: 100px;
    }

    .catalog__items.list .catalog__item__des-rating,
    .catalog__items.list .catalog__item__des-info {
        display: none;
    }

    .hs-modal__window__top {
        background: #fff;
        color: #000;
    }

    .hs-modal__window__top-a {
        display: none;
    }
    .article_pic_default{
        max-width: 100%;
    }
    .article_content--default p{
        text-align: justify;
    }
}

@media (max-width: 688px){
    .fa.fa-caret-down:before{
        display: inline;
    }
}

@media (max-width: 640px) {

    .catalog__items.list .catalog__item__title-w {
        width: 150px;
    }
    .catalog__filter-types__item{
        display: none;
    }


    .header__shop-line__button-a-icon.icon-promo{
        display: none;
    }
    .header__shop-line__button__coupon{
        padding: 12px 2px;
    }
}

@media (max-width: 550px) {

    .loginned-user {
      width: 100%;
      text-align: center;
    }

    .user-page-link {
      width: 50%;
      text-align: center;
    }

    .user-page-link a, .logout-link a{
      width: 100%;

    }

    .logout-link {
      width: 30%;
      text-align: center;
    }

    .catalog__item {
        width: 100%;
    }
    .slider-stock,.stock__item, .home-catalog-types, .home-text, .footer-w, .home-news,
    /*.slider-stock__slider, .slider__item,*/
    .slider-stock__stock,
    .catalog-types__item {
        width: 100%;
    }
    .h-phones .item.midi:first-child{
        margin: 0 0px 14px 0;
    }

    .explan H1 {
        font-size: 2em;
    }
    .catalog__items.list .catalog__item__des__column--hidemobile,
    .catalog__items.list .catalog__item__des-rating, .catalog__items.list .catalog__item__des-info {
        display: inherit;
    }
    .catalog__items.list .catalog__item__title-w,.catalog__items.list .catalog__item__des-w {
        width: inherit;
    }
    .catalog__items.list .catalog__item__image-w{
        float: inherit;
    }
    .catalog__items.list .catalog__item__des-w{
        float: none;
    }
    .catalog__items.list .catalog__item__title{
        height: inherit;
    }

    .header__shop-line__button__coupon {
        height: 38px;
        padding: 0;
        padding-top: 9px;
        width: 100%;
        text-align: center;
        border: none;
        border-left: none;
    }
    .header__info__ad-header,.header__info__phone-a{
        font-size: 12px;
        line-height: 12px;
    }
    .header__info__logo {
        /*width: 125px;*/
        width: 100%;
        height: 100%;
        text-align: center;
    }

    .header__info__ad{
        padding: 0;
        margin: 0;
        font-size: inherit;
        line-height: inherit;
        padding-bottom: 3px;
        width: 100%;
    }

    .header__info__ad-des{
        font-size: 10px;
    }

    .header__shop-line__button-a-icon{
        margin: 0 3px -4px 0;
    }
    .header__shop-line__button__coupon__input {
        width: 60%;
        text-align: center;
    }
    .header__shop-line__button--input {
        border-left: none;
        width: 90px;
    }
    .header__shop-line__button__coupon__input::-webkit-input-placeholder{
        color:transparent;
    }
    .header__shop-line__button__coupon__input::-webkit-input-placeholder::before{
        content:'Промокод';
        color:#2f9c0e;
    }

    .header__shop-line{
        padding: 0;
        text-align: left;
    }
    .basket_title {
        display: none;
    }
    .content{
        padding: 0;
    }
    .slider-stock__slider{
        height: 180px;
    }
    .slider-stock__stock{
        margin: 0;
    }
}
@media (max-width: 540px) {
    #acc_original-container .buttons--hide{
        display: inherit;
    }

}
@media (max-width: 400px) {
    .slider-stock__slider {
        margin: 0 auto;
    }
    .catalog__item {
        width: 100%;
    }

    .home-news__items,.home-news__item,.home-news__items-column{
        width: 100%;
    }
    .home-news__item{
        float: none;
        display: block;
        padding: 0 1em;
    }
    .content .h-phones{
        overflow: hidden;
    }
    /*.slider-stock,*/
    .slider-stock__slider, .slider__item
    {
        width: 320px;
    }
    .stock__item-des,
    .home-news__items-column:nth-child(n+2),
    .home-news__nav,
    /*.home-news__item-date,*/
    .footer__info__error
    {
        display: none;
    }
    .footer-w,.home-text{
        padding:0 1em;
    }

    .home-news__item-date{
        position: relative;
        text-align: center;
    }

    .modal-footer button:first-child {
      margin-bottom: 10px;
    }

    .stock__item-type {
      padding-left: 35px;
      width: 85px;
    }

    .stock__item-type::after {
      left: 65px;
    }
}

@media (max-width: 470px) {

    .catalog__items.list .catalog__item__preview {
        display: none;
    }

    .footer-body-fix {
        height: 370px;
    }

    .footer {
        margin-top: -370px;
    }

}
/* End */



/* Start:/bitrix/templates/shop/components/bitrix/sale.basket.basket.line/header/style.css*/
.header_basket-w {
    position: relative;
}

#basket__list-my {
    display: none;
    position: absolute;
    top: 38px;
    right: -3px;
    min-width: 140px;
    line-height: normal;
    background-color: #fff;
    padding: 20px;
    text-align: left;
    box-shadow: 0px 3px 6px -2px #868686;
    z-index: 9999;
}

.basket__list__item {
    clear: both;
    margin: 0 0 20px;
}

.basket__list__item-img-w {
    float: left;
    width: 50px;
    height: 50px;
    text-align: center;
}

.basket__list__item-img {
    max-width: 50px;
    max-height: 50px;
}

.basket__list__item-name,
.basket__list__item-price {
    margin-left: 70px;
    width: 260px;
    white-space: normal;
}

.basket__list__item-name {
    padding-top: 0;
}

.basket__list__item-price {
    position: relative;
}

.basket__list__item-price-text {
    position: absolute;
    left: 20px;
}

.basket__list__item-name-a {
    color: #000;
}

.basket__list__item-name-a:hover {
    color: #0099d8;
}

.basket__list__item-name {
    text-transform: uppercase;
    font-weight: bold;
}

.basket__list__item-price-text,
.basket__all__price-text {
    color: #0099d8;
    font-weight: bold;
}


.basket__all__price {
    position: relative;
    line-height: 32px;
    border-bottom: 1px solid #e8e8e8;
    border-top: 1px solid #e8e8e8;
}

.basket__all__price--delayed{
    position: relative;
    line-height: 32px;
    border-bottom: 1px solid #e8e8e8;
}

.basket__all__price-text {
    position: absolute;
    top: 0;
    right: 0;
}


.basket__order-w {
    margin: 20px 0 0;
    text-align: center;
}

.basket__order-a {
    display: inline-block;
    line-height: 32px;
    padding: 0 14px;
    border: 1px solid #000;
    color: #000;
    text-transform: uppercase;
    font-weight: bold;
}

.basket__order-a:hover {
    border-color: #0099d8;
    color: #0099d8
}

/* End */



/* Start:/bitrix/templates/shop/components/wsm/callback/zvonok/style.css*/
#header .tel {
	z-index: 2;
}
#wsm_Callback {
	/*position: absolute !important;*/
	z-index: 2;
	}
#wsm_Callback .openForm{
	position: relative;
	display: inline-block;
	line-height: 100%;
	font-size: 16px;
	color: #2A99EA;
	border-bottom: 1px dashed #2A99EA !important;
	text-decoration: none;
	cursor: pointer;
	}


#wsm_Callback .callback_form{
	position: absolute !important;
	left: -64px;
	top: -13px;
	z-index: 2;
	width: 200px;

	border: 0px solid #cccccc;
	padding: 15px 15px 10px 15px;
	background: #fff;
	display: none;
	text-align: left !important;

	-webkit-box-shadow: 0 0px 10px rgba(0, 0, 0, 0.6);
		-moz-box-shadow: 0 0px 10px rgba(0, 0, 0, 0.6);
			box-shadow: 0 0px 10px rgba(0, 0, 0, 0.6);
}

#wsm_Callback a.close{
	position: absolute;
	display: block;
	top: 0px;
	margin: 0px 3px 0px 0px;
	padding: 7px;
	font-size: 12px;
	right: 0px;
	color: #EA3F2A;
	text-decoration: none;
	cursor: pointer;
	font-weight: bold;
}

#wsm_Callback .callback_form h2{ text-transform: uppercase; font-size: 16px !important; color: #0078A5; margin: 0px 0px 6px 0px; padding: 0px 0px 4px 0px; cursor: pointer; display: block; border: none; line-height: 100%; }
#wsm_Callback .callback_form .line{ display: block; margin: 0px 0px 10px 0px; }
#wsm_Callback .callback_form .line .red{color: red;}
#wsm_Callback .callback_form .line label{ display: block; width: 100%; margin: 2px 0px 4px 0px; clear: both;}
#wsm_Callback .callback_form .line  .hour {
	width: 100%;
	margin: 0px;
	padding: 0px;
	display: block;
}

#wsm_Callback input[type="text"], #wsm_Callback select{
	margin: 0px 0px;
	color: #313131;
	width: 100%;
	padding: 4px 4px;
	border: 1px solid #c1c1c1;

	-moz-box-sizing: border-box;
    -webkit-box-sizing: border-box;
    box-sizing: border-box;
}

#wsm_Callback input.phone{
    width:180px !important;
}

#wsm_Callback select{
	width: 100%;
	}

#wsm_Callback input[type="text"]:hover, #wsm_Callback input[type="text"]:active{
	-webkit-box-shadow: 0 0px 9px rgba(0, 0, 0, 0.3); /*308FE8*/
		-moz-box-shadow: 0 0px 9px rgba(0, 0, 0, 0.3);
			box-shadow: 0 0px 9px rgba(0, 0, 0, 0.3);

	-webkit-transition: box-shadow linear 0.4s;
     -moz-transition: box-shadow linear 0.4s;
       -o-transition: box-shadow linear 0.4s;
          transition: box-shadow linear 0.4s;
}


#wsm_Callback input[type="text"].error, #wsm_Callback input[type="text"].error:hover{
	border: 1px solid #f00;
	}


#wsm_Callback .callback_form  .line  .hour em{
	margin-right: 5px;
	display: inline-block;
	min-width: 10px;
}

#wsm_Callback .hour input[type="text"]{width: 65px;}
#wsm_Callback .hour input[type="text"]:first{ margin-right: 20px;}



#wsm_Callback input[type="submit"]{

	position: relative;
	cursor: pointer;
	font-family: 'Exo 2', sans-serif;
	font-size: 16px;
	font-weight: 600;
	color: #fff;
	height: 32px;
	background-color: #fff;
	border: 0 none;
	border-radius: 0;
	text-transform: uppercase;
	background-color: #1b98e0;
	display: block;
	width: 136px;
	margin: 16px auto 0;
}


#wsm_Callback input[type="submit"]:disabled{
	background: #ccc;

	-webkit-box-shadow: 0 0px 4px rgba(250, 0, 0, 0.5);
		-moz-box-shadow: 0 0px 4px rgba(250, 0, 0, 0.5);
			box-shadow: 0 0px 4px rgba(250, 0, 0, 0.5);

	-webkit-transition: box-shadow linear 0.2s;
     -moz-transition: box-shadow linear 0.2s;
       -o-transition: box-shadow linear 0.2s;
          transition: box-shadow linear 0.2s;
}

.message{
	display: none;
	padding: 5px;
	margin: 0px 0 10px 0;
	border: 1px solid #ccc;
	line-height: 150%;
	width: 200px;
	font-size: 10px;
	-moz-box-sizing: border-box; /* Для Firefox */
    -webkit-box-sizing: border-box; /* Для Safari и Chrome */
    box-sizing: border-box; /* Для IE и Opera */
	}
.message.error{
	color: red;
	border: 1px solid #f00;
	}
.message.sucess{
	color: green;
	border: 1px solid green;
	}
/* End */



/* Start:/bitrix/templates/shop/components/bitrix/breadcrumb/shop/style.css*/
.breadcrumbs__wrap {
    width: 100%;
    border-bottom: 1px solid #dddddd;
    background-color: #f3f3f3;
}

.breadcrumbs{
    width: 1170px;
    margin: 0 auto;
    border: none;
    padding: 0;
    line-height: 26px;
}
.breadcrumbs__item {
    color: #626262;
    font-size: 12px;
    margin: 0 6px;
}

@media (max-width: 1220px){
    .breadcrumbs {
        width: 938px;
    }
}

@media (max-width: 960px){
    .breadcrumbs {
        width: 480px;
    }
}

@media (max-width: 480px){
    .breadcrumbs {
        width: 100%;
    }
}

.attach-photo {
  background: url(../data/images/attach.png) no-repeat !important;
  background-position: center center !important;
  background-size: 20px 20px !important;
  height: 34px;
  width: 34px;
  border-radius: 0px !important;
  border-left: none !important;
}

.attach-photo:hover {
    background-color: #e6e6e6 !important;
}

.goods_of_the_day {
  margin-top: 10px;
  /*margin-left: 200px;*/
  background-color: #fff;
  /*height: 80px;*/
  width: 100%;
}

.goods_of_the_day h2 {
  width: 200px;
  float: left;
  padding: 0 0 0 20px;
}

.good_of_the_day-block:hover {
  z-index: 10;
border-color: #2f9c0e;
position: relative;
/*background-color: #ececec;*/
}

.good_of_the_day-block:hover .good_of_the_day-name {
  color: #2f9c0e;
}

.good_of_the_day-block {
  height: 70px;
  padding: 5px;
  background-color: #fff;
  margin: 5px 0 0 -1px;
  overflow: hidden;
  border: 1px solid #ddd;
  width: 320px;
  float: left;
  /*margin-left: 5px;*/

}

.good_of_the_day-img-block {
  width: 60px;
  height: 60px;
  overflow: hidden;
  position: relative;
  float: left;
}


.good_of_the_day-img-block-wrap, .stock__item-image-wrap {
  position: absolute;
	width: 2000px;
	height: 2000px;
	margin: -1000px 0 0 -1000px;
	left: 50%;
	top: 50%;
	text-align: center;
	line-height: 2000px;
}

.stock__item-img {
  vertical-align: middle;
  min-width: 80px;
  max-height: 60px;
}

.good_of_the_day-img {
  vertical-align: middle;
  min-width: 70px;
  min-height: 70px;
}

.good_of_the_day-name-block {
  float: left;
  margin-left: 10px;
}

.good_of_the_day-name {
  width: 200px;
  font-size: 14px;
  color: #222;
}

.goods_of_the_day-title {
  padding-top: 0px;
  margin-top: 10px;
  margin-left: 20px;
}

@media (max-width: 1350px) {

    .good_of_the_day-block {
      margin-left: 20px;
    }

}

html {
      background-color: #f3f3f3;
}

@media (max-width: 790px){
.catalog__column-left {

  }
}

.field-name {
  width: 120px;
}

.sizes-head {
  font-weight: bold;
  margin-bottom: 5px;
}

.size-field {
  margin-bottom: 5px;
}

.size-tr-bottom-border {margin: 0 10px;

border-bottom: 1px solid #BBB;
margin-bottom: 5px;
position: relative;
bottom: 0;
clear: both;}

@media (max-width: 490px){
  .size-field {
    text-align: center;
  }
}
/* End */
/* /js/libs/jquery.simplemodal/basic.css */
/* /js/libs/jquery.simplemodal/basic_ie.css */
/* /js/libs/bukvus/bukvus.css */
/* /bitrix/templates/shop/css/style.css */
/* /bitrix/templates/shop/css/media.css */
/* /bitrix/templates/shop/components/bitrix/sale.basket.basket.line/header/style.css */
/* /bitrix/templates/shop/components/wsm/callback/zvonok/style.css */
/* /bitrix/templates/shop/components/bitrix/breadcrumb/shop/style.css */
